## 7.1.0.20241020 (2024-10-20)

Update mypy to 1.12.0 (#12859)

## 7.1.0.20240711 (2024-07-11)

[flake8] Improve `Statistic` typing (#12313)

Add `_write` method to `flake8.formatting.BaseFormatter` (#12312)

It is very useful for real-life custom formatters. Example: https://github.com/wemake-services/wemake-python-styleguide/blob/470d81174684eb9a175603aec02f0ac6589b8acd/wemake_python_styleguide/formatter.py#L92-L96

Definition: https://github.com/PyCQA/flake8/blob/65a38c42a7f1a05ff8d99b313160754fc9b7a0d8/src/flake8/formatting/base.py#L173-L178

## 7.1.0.20240616 (2024-06-16)

[stubsabot] Bump flake8 to 7.1.* (#12139)

Release: https://pypi.org/pypi/flake8/7.1.0
Homepage: https://github.com/pycqa/flake8
Repository: https://github.com/pycqa/flake8
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/flake8
Diff: https://github.com/pycqa/flake8/compare/7.0.0...7.1.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 7.
 - Total lines of Python code deleted: 3.

## 7.0.0.20240519 (2024-05-19)

Use assignment instead of annotation in third party enums (#11957)

## 7.0.0.20240511 (2024-05-11)

Add flake8 (#11676)

